CountryModel class
Wraps Country from country_picker with optional detailed national format.
Properties
- code → String
-
no setter
- country → Country
-
Underlying
country_pickervalue (dial code, ISO code, localized name, etc.).no setter - dialCode → String
-
no setter
- example → String
-
no setter
- flag → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int
-
no setter
- minLength → int
-
no setter
- name → String
-
no setter
- pattern → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCountry(
Country country) → CountryModel -
getByCode(
String code) → CountryModel -
Resolve by ISO 3166-1 alpha-2 (e.g.
BD,US). Falls back to United States. -
getCountries(
) → List< CountryModel> -
All geographic countries from
country_picker(typically 240+). -
searchCountries(
String query) → List< CountryModel>